==> org.eclipse.jdt.core.manipulation.source_1.19.100.v20230811-2104.jar: org/eclipse/jdt/internal/corext/fix/LibStandardNames.java <==
/*******************************************************************************
 * Copyright (c) 2021 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Carsten Hammer
 *******************************************************************************/
package org.eclipse.jdt.internal.corext.fix;

public class LibStandardNames {
	static final String METHOD_GET_PROPERTY= "getProperty"; //$NON-NLS-1$
	static final String METHOD_DISPLAY_NAME= "displayName"; //$NON-NLS-1$
	static final String METHOD_DEFAULT_CHARSET= "defaultCharset"; //$NON-NLS-1$
	static final String METHOD_GET_SEPARATOR= "getSeparator"; //$NON-NLS-1$
	static final String METHOD_GET_PATH_SEPARATOR= "getPathSeparator"; //$NON-NLS-1$
	static final String METHOD_GET_DEFAULT= "getDefault"; //$NON-NLS-1$
	static final String METHOD_LINE_SEPARATOR= "lineSeparator"; //$NON-NLS-1$
	static final String METHOD_BOOLEAN= "getBoolean"; //$NON-NLS-1$
	static final String METHOD_INTEGER= "getInteger"; //$NON-NLS-1$
	static final String METHOD_LONG= "getLong"; //$NON-NLS-1$
	static final String METHOD_PARSEBOOLEAN= "parseBoolean"; //$NON-NLS-1$
	static final String METHOD_PARSEINTEGER= "parseInt"; //$NON-NLS-1$
	static final String METHOD_PARSELONG= "parseLong"; //$NON-NLS-1$
	static final String FIELD_PATH_SEPARATOR= "pathSeparator"; //$NON-NLS-1$
	static final String FIELD_SEPARATOR= "separator"; //$NON-NLS-1$
	static final String METHOD_FOREACH= "forEach"; //$NON-NLS-1$
}

==> org.eclipse.jdt.core.manipulation.source_1.23.100.v20250806-2349.jar: org/eclipse/jdt/internal/corext/fix/LibStandardNames.java <==
/*******************************************************************************
 * Copyright (c) 2021 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Carsten Hammer
 *******************************************************************************/
package org.eclipse.jdt.internal.corext.fix;

public class LibStandardNames {
	static final String METHOD_GET_PROPERTY= "getProperty"; //$NON-NLS-1$
	static final String METHOD_DISPLAY_NAME= "displayName"; //$NON-NLS-1$
	static final String METHOD_DEFAULT_CHARSET= "defaultCharset"; //$NON-NLS-1$
	static final String METHOD_GET_SEPARATOR= "getSeparator"; //$NON-NLS-1$
	static final String METHOD_GET_PATH_SEPARATOR= "getPathSeparator"; //$NON-NLS-1$
	static final String METHOD_GET_DEFAULT= "getDefault"; //$NON-NLS-1$
	static final String METHOD_LINE_SEPARATOR= "lineSeparator"; //$NON-NLS-1$
	static final String METHOD_BOOLEAN= "getBoolean"; //$NON-NLS-1$
	static final String METHOD_INTEGER= "getInteger"; //$NON-NLS-1$
	static final String METHOD_LONG= "getLong"; //$NON-NLS-1$
	static final String METHOD_PARSEBOOLEAN= "parseBoolean"; //$NON-NLS-1$
	static final String METHOD_PARSEINTEGER= "parseInt"; //$NON-NLS-1$
	static final String METHOD_PARSELONG= "parseLong"; //$NON-NLS-1$
	static final String FIELD_PATH_SEPARATOR= "pathSeparator"; //$NON-NLS-1$
	static final String FIELD_SEPARATOR= "separator"; //$NON-NLS-1$
	static final String METHOD_FOREACH= "forEach"; //$NON-NLS-1$
	static final String METHOD_VERSION= "version"; //$NON-NLS-1$
	static final String METHOD_TOSTRING= "toString"; //$NON-NLS-1$
	static final String METHOD_FEATURE= "feature"; //$NON-NLS-1$
}
